#include <genesis.h> //include genesis header file

#include <sprite.h>

// sprites structure (pointer of Sprite)
Sprite* sprites[1];

fix32 xCoord = 0;
fix32 yCoord = 0;
s16 xCMD = 0;
s16 yCMD = 0;
char str1[8];
char str2[8];

void joyEvent( u16 joy, u16 changed, u16 state)
{
	if (joy == JOY_1) //Player 1 port
	{
		if (state & BUTTON_UP) //UP button pressed
		{
			yCMD = -1;
		}
		else if (state & BUTTON_DOWN) //DOWN button pressed
		{
			yCMD = +1;
		}
		else //Both UP and DOWN button released
		{
			yCMD = 0;
		}
        if (state & BUTTON_LEFT) //LEFT button pressed
		{
			xCMD = -1;
		}
		else if (state & BUTTON_RIGHT) //RIGHT button pressed
		{
			xCMD = +1;
		}
		else //Both LEFT and RIGHT button released
		{
			xCMD = 0;
		}
	}
}

static void movePC()
{
    xCoord += xCMD;
    yCoord += yCMD;

    // set sprites position
    SPR_setPosition(sprites[0], fix32ToInt(xCoord), fix32ToInt(yCoord));
}

// main loop
int main()
{
    // disable interrupt when accessing VDP
    SYS_disableInts();

    // Initialize the video processor, set screen resolution to 320x224
    VDP_init();
    VDP_setScreenWidth320();
    VDP_setScreenHeight224();

    VDP_drawText("x:", 18, 22);
    VDP_drawText("y:", 18, 23);

    // VDP process done, we can re enable interrupts
    SYS_enableInts();

    JOY_init(); //reset controller handler
	JOY_setEventHandler( &joyEvent ); //register joyEvent function to be called

    // init sprites engine
    SPR_init(16, 256, 256);

    // init ring (test player) sprite
    VDP_setPalette(PAL1, ring_sprite.palette->data);
    sprites[0] = SPR_addSprite(&ring_sprite, fix32ToInt(xCoord), fix32ToInt(yCoord), TILE_ATTR(PAL1, TRUE, FALSE, FALSE));
    SPR_update();

    //repeat forever
    while(TRUE)
    {
        movePC();
        SPR_update();
        intToStr(xCoord, str1, 1);
        intToStr(yCoord, str2, 1);
        VDP_drawText("     ", 21, 22);
        VDP_drawText("     ", 21, 23);
        VDP_drawText(str1, 21, 22);
        VDP_drawText(str2, 21, 23);
        VDP_waitVSync(); //wait for screen refresh
    }
	return (0);
}
